# grader_helper
 
Need to make the renaming folders function skip folders that have already been renamed so that I can run the function multiple times without renaming the same folders over and over again. 

